from setuptools import setup

setup(
    name='cast_from_env',
    version='0.0.5',
    description='Get and cast environment variables',
    author='Nic Wolff',
    author_email='nwolff@hearst.com',
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url='http://github.com/Media-Platforms/cast-from-env',
    py_modules=['cast_from_env'],
)
